jenkins-bot has submitted this change and it was merged.

Change subject: Create all templates Flow uses
......................................................................


Create all templates Flow uses

Content was inspired by mediawiki.org.

Bug: T105421
Change-Id: I0a50d066c3aead1f988ceeaefed9dd0ea40704fa
---
M i18n/en.json
M i18n/qqq.json
M maintenance/FlowCreateTemplates.php
3 files changed, 41 insertions(+), 4 deletions(-)

Approvals:
  Catrope: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/i18n/en.json b/i18n/en.json
index 36203d3..7a5da6c 100644
--- a/i18n/en.json
+++ b/i18n/en.json
@@ -407,12 +407,19 @@
        "flow-topic-undo-delete": "undo delete",
        "flow-topic-undo-suppress": "undo suppress",
        "flow-importer-lqt-moved-thread-template": "LQT Moved thread stub 
converted to Flow",
+       "flow-importer-lqt-moved-thread-template-content": "This post by 
{{{author}}} was moved on {{{date}}}.  You can find it at [[{{{title}}}]].",
        "flow-importer-lqt-converted-template": "LQT page converted to Flow",
+       "flow-importer-lqt-converted-template-content": "Previous page history 
was archived for backup purposes at <span 
class='flow-link-to-archive'>[[{{{archive}}}]]</span> on {{#time: 
Y-m-d|{{{date}}} }}.",
        "flow-importer-lqt-converted-archive-template": "Archive for converted 
LQT page",
+       "flow-importer-lqt-converted-archive-template-content": "This page is 
an archived LiquidThreads page. '''Do not edit the contents of this page'''. 
Please direct any additional comments to the [[{{{from}}}|current talk page]].",
        "flow-importer-wt-converted-template": "Wikitext talk page converted to 
Flow",
+       "flow-importer-wt-converted-template-content": "Previous discussion was 
archived at <span class='flow-link-to-archive'>[[{{{archive}}}]]</span> on 
{{#time: Y-m-d|{{{date}}} }}.",
        "flow-importer-wt-converted-archive-template": "Archive for converted 
wikitext talk page",
+       "flow-importer-wt-converted-archive-template-content": "This page is an 
archive. '''Do not edit the contents of this page'''. Please direct any 
additional comments to the [[{{{from|{{TALKSPACE}}:{{BASEPAGENAME}}}}}|current 
talk page]].",
        "flow-importer-lqt-suppressed-user-template": "LQT post imported with 
supressed user",
+       "flow-importer-lqt-suppressed-user-template-content": "This revision 
was imported from LiquidThreads with a suppressed user. It has been reassigned 
to the current user.",
        "flow-importer-lqt-different-author-signature-template": "LQT post 
imported with different signature user",
+       "flow-importer-lqt-different-author-signature-template-content": 
"''This post was posted by [[User:{{{authorUser}}}|{{{authorUser}}}]], but 
signed as [[User:{{{signatureUser}}}|{{{signatureUser}}}]].''",
        "apihelp-flow-description": "Allows actions to be taken on Flow pages.",
        "apihelp-flow-param-submodule": "The Flow submodule to invoke.",
        "apihelp-flow-param-page": "The page to take the action on.",
diff --git a/i18n/qqq.json b/i18n/qqq.json
index 9f0d424..837469c 100644
--- a/i18n/qqq.json
+++ b/i18n/qqq.json
@@ -414,12 +414,19 @@
        "flow-topic-undo-delete": "Automatic moderation summary when undoing a 
topic deletion that was just performed.",
        "flow-topic-undo-suppress": "Automatic moderation summary when undoing 
a topic suppression that was just performed.",
        "flow-importer-lqt-moved-thread-template": "Name of a wikitext template 
that is used as the content of LQT moved thread stubs when they are imported to 
Flow.",
+       "flow-importer-lqt-moved-thread-template-content": "Content of the 
Template:{{msg-mw|flow-importer-lqt-moved-thread-template}} page, informing 
people the LiquidThreads post was moved. Available template params: 
{{{author}}}, {{{date}}}, {{{title}}}.",
        "flow-importer-lqt-converted-template": "Name of a wikitext template 
that is added to the description of Flow boards that were converted from 
LiquidThreads",
+       "flow-importer-lqt-converted-template-content": "Content of the 
Template:{{msg-mw|flow-importer-lqt-converted-template}} page, informing people 
where to find the LiquidThreads history. Available template params: 
{{{archive}}}, {{{date}}}.",
        "flow-importer-lqt-converted-archive-template": "Name of a wikitext 
template that is added to the archived copy of a LiquidThreads page converted 
to Flow.",
+       "flow-importer-lqt-converted-archive-template-content": "Content of the 
Template:{{msg-mw|flow-importer-lqt-converted-archive-template}} page, 
informing people this is an archived LiquidThreads page. Available template 
params: {{{from}}}.",
        "flow-importer-wt-converted-template": "Name of a wikitext template 
that is added to the description of a Flow boards that were converted from 
Wikitext",
+       "flow-importer-wt-converted-template-content": "Content of the 
Template:{{msg-mw|flow-importer-wt-converted-template}} page, informing people 
this wikitext discussion is archived. Available template params: {{{archive}}}, 
{{{date}}}.",
        "flow-importer-wt-converted-archive-template": "Name of a wikitext 
template that is added to the archived copy of a wikitext talk page converted 
to Flow.",
+       "flow-importer-wt-converted-archive-template-content": "Content of the 
Template:{{msg-mw|flow-importer-wt-converted-archive-template}} page, informing 
people this is an archived wikitext discussion. Available template params: 
{{{from}}}.",
        "flow-importer-lqt-suppressed-user-template": "Name of a wikitext 
template that is added to a revision imported from liquidthreads that is owned 
by a suppressed user.",
+       "flow-importer-lqt-suppressed-user-template-content": "Content of the 
Template:{{msg-mw|flow-importer-lqt-suppressed-user-template}} page, informing 
people this revision was imported from LiquidThreads with a suppressed user and 
has been reassigned to the current user.",
        "flow-importer-lqt-different-author-signature-template": "Name of a 
wikitext template used when the post author and post signature differ.  The 
template takes two parameters:\nauthorUser - Username (or IP) that posted the 
post.\nsignatureUser- Username (or IP) that the post is signed as",
+       "flow-importer-lqt-different-author-signature-template-content": 
"Content of the 
Template:{{msg-mw|flow-importer-lqt-different-author-signature-template}} page, 
informing people this LiquidThreads post was posted by a different user than it 
was signed as. Available template params: {{{authorUser}}}, 
{{{signatureUser}}}.",
        "apihelp-flow-description": "{{doc-apihelp-description|flow}}",
        "apihelp-flow-param-submodule": "{{doc-apihelp-param|flow|submodule}}",
        "apihelp-flow-param-page": "{{doc-apihelp-param|flow|page}}",
diff --git a/maintenance/FlowCreateTemplates.php 
b/maintenance/FlowCreateTemplates.php
index 44fac0e..817cd7b 100644
--- a/maintenance/FlowCreateTemplates.php
+++ b/maintenance/FlowCreateTemplates.php
@@ -5,9 +5,8 @@
        : dirname( __FILE__ ) . '/../../../maintenance/Maintenance.php' );
 
 /**
- * Creates Template:FlowMention, which is used to render mentions in Flow's 
Visual Editor.
  * The template will be created with a default format, but can be customized.
  * If the template already exists, it will be left untouched.
  *
  * @ingroup Maintenance
  */
@@ -24,6 +23,7 @@
         */
        protected function getTemplates() {
                return array(
+                       // Template:FlowMention, used to render mentions in 
Flow's Visual Editor
                        'flow-ve-mention-template-title' => function( Title 
$title ) {
                                // get "User:" namespace prefix in wiki language
                                global $wgContLang;
@@ -31,13 +31,36 @@
 
                                return '@[[' . $namespaces[NS_USER] . 
':{{{1|Example}}}|{{{2|{{{1|Example}}}}}}]]';
                        },
+                       // LiquidThread import templates
+                       'flow-importer-lqt-moved-thread-template' => function( 
Title $title ) {
+                               return wfMessage( 
'flow-importer-lqt-moved-thread-template-content' 
)->inContentLanguage()->plain();
+                       },
+                       'flow-importer-lqt-converted-template' => function( 
Title $title ) {
+                               return wfMessage( 
'flow-importer-lqt-converted-template-content' )->inContentLanguage()->plain();
+                       },
+                       'flow-importer-lqt-converted-archive-template' => 
function( Title $title ) {
+                               return wfMessage( 
'flow-importer-lqt-converted-archive-template-content' 
)->inContentLanguage()->plain();
+                       },
+                       'flow-importer-lqt-suppressed-user-template' => 
function( Title $title ) {
+                               return wfMessage( 
'flow-importer-lqt-suppressed-user-template-content' 
)->inContentLanguage()->plain();
+                       },
+                       'flow-importer-lqt-different-author-signature-template' 
=> function( Title $title ) {
+                               return wfMessage( 
'flow-importer-lqt-different-author-signature-template-content' 
)->inContentLanguage()->plain();
+                       },
+                       // Wikitext import templates
+                       'flow-importer-wt-converted-template' => function( 
Title $title ) {
+                               return wfMessage( 
'flow-importer-wt-converted-template-content' )->inContentLanguage()->plain();
+                       },
+                       'flow-importer-wt-converted-archive-template' => 
function( Title $title ) {
+                               return wfMessage( 
'flow-importer-wt-converted-archive-template-content' 
)->inContentLanguage()->plain();
+                       },
                );
        }
 
        public function __construct() {
                parent::__construct();
 
-               $this->mDescription = "Creates Template:FlowMention, which is 
used te render mentions in Flow's Visual Editor";
+               $this->mDescription = "Creates templates required by Flow";
        }
 
        protected function getUpdateKey() {
@@ -5,9 +5,8 @@
Visual Editor.
- * The template will be created with a default format, but can be customized.
- * If the template already exists, it will be left untouched.
+ * The templates will be created with a default content, but can be customized.
+ * If the templates already exists, they will be left untouched.
  *
  * @ingroup Maintenance

-- 
To view, visit https://gerrit.wikimedia.org/r/232489
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I0a50d066c3aead1f988ceeaefed9dd0ea40704fa
Gerrit-PatchSet: 3
Gerrit-Project: mediawiki/extensions/Flow
Gerrit-Branch: master
Gerrit-Owner: Matthias Mullie <[email protected]>
Gerrit-Reviewer: Catrope <[email protected]>
Gerrit-Reviewer: Mattflaschen <[email protected]>
Gerrit-Reviewer: Matthias Mullie <[email protected]>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to